@@ -1,8 +1,10 @@
 from dataclasses import dataclass
-from typing import Callable
+from typing import Callable, Optional
 import requests
 from requests_oauthlib import OAuth2Session
 from etsy_apiv3.utils.RequestException import EtsyRequestException
+from etsy_apiv3.models.UserModel import OtherUser
+
 
 def token_saver(token):
     return token
@@ -19,8 +21,18 @@ class EtsyAuth:
     
     headers: dict
     session: OAuth2Session
-    __base_endpoint:str = "https://openapi.etsy.com/v3/application"
+    user_info: Optional[OtherUser]
+    __base_endpoint:str = "https://openapi.etsy.com/v3/application/"
     
+    
+    def __post__init__(self):
+        user_info_endpoint = "oauth/userinfo"
+        
+        response = self.request("GET", user_info_endpoint)
+        
+        self.user_info = OtherUser(**response)
+        
+        
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
         """ 
         Send Request to target endpoint by method
@@ -42,7 +54,7 @@ class EtsyAuth:
         else:
             headers = self.headers
             
-        url = f"{self.__base_endpoint}/{endpoint}"
+        url = f"{self.__base_endpoint}{endpoint}"
         req: requests.Response = self.session.request(method, url, headers=headers, *args, **kwargs)
         
         response: dict = req.json()
@@ -52,6 +64,8 @@ class EtsyAuth:
         
         return response
 
+    
+    
 
 
 class EtsySession:
